"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const constants_1 = require("../../constants");
const event_1 = require("./event");
/**
 * Describes a BPMN EndEvent.
 * These are used to finish a process.
 *
 * Depending on the type of EndEvent used, the process will either be finished
 * with a success message or an error.
 */
class EndEvent extends event_1.Event {
    get bpmnType() {
        return constants_1.BpmnType.endEvent;
    }
    get eventType() {
        const eventIsErrorEvent = this.errorEventDefinition !== undefined;
        if (eventIsErrorEvent) {
            return constants_1.EventType.errorEvent;
        }
        const eventIsMessageEvent = this.messageEventDefinition !== undefined;
        if (eventIsMessageEvent) {
            return constants_1.EventType.messageEvent;
        }
        const eventIsSignalEvent = this.signalEventDefinition !== undefined;
        if (eventIsSignalEvent) {
            return constants_1.EventType.signalEvent;
        }
        const eventIsTerminateEvent = this.terminateEventDefinition !== undefined;
        if (eventIsTerminateEvent) {
            return constants_1.EventType.terminateEvent;
        }
        return undefined;
    }
}
exports.EndEvent = EndEvent;
//# sourceMappingURL=end_event.js.map